package listviews;

import java.util.ArrayList;

import javafx.application.Application;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.ComboBox;
import javafx.scene.control.ListView;
import javafx.scene.control.SelectionMode;
import javafx.scene.control.TableColumn;
import javafx.scene.control.TableView;
import javafx.scene.control.TreeItem;
import javafx.scene.control.TreeView;
import javafx.scene.control.cell.PropertyValueFactory;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

public class ListViewsDemo extends Application {
	
	// tableView Data
	final ObservableList<Person> data = FXCollections.observableArrayList(
		    new Person("Jacob", "Smith", "jacob.smith@example.com"),
		    new Person("Isabella", "Johnson", "isabella.johnson@example.com"),
		    new Person("Ethan", "Williams", "ethan.williams@example.com"),
		    new Person("Emma", "Jones", "emma.jones@example.com"),
		    new Person("Michael", "Brown", "michael.brown@example.com")
	);
	
    public static void main(String[] args) {
        launch(args);
    }

    @Override
    public void start(Stage primaryStage) throws Exception {
    	// Set ChoiseBox - drop down menu
    	ChoiceBox<String> choiceBox = new ChoiceBox<>();
        choiceBox.getItems().add("Option 1");
        choiceBox.getItems().add("Option 2");
        choiceBox.getItems().addAll("Option 3", "Option 4");
        choiceBox.setValue("Option 2");
        
        //choiceBox.setOnAction( e -> 
        //			System.out.println("User selected " + choiceBox.getValue()));
        choiceBox.getSelectionModel().selectedItemProperty().addListener(
        		(v, oldValue, newValue) -> {
        	System.out.println("Previous selection " + oldValue 
        			+ ", new selection " + newValue);
        });
        
        //Button
        Button cbButton = new Button("Ok");
        cbButton.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				String message = "Selected choise: " + choiceBox.getValue();
		        System.out.println(message);
			}
        });

        //Layout
        VBox cbLayout = new VBox(10);
        cbLayout.setPadding(new Insets(20, 20, 20, 20));
        cbLayout.getChildren().addAll(choiceBox, cbButton);
        
        //----------------------------------------------------------------------
     
        // Set ComboBox 
        ComboBox<String> comboBox = new ComboBox<>();
        comboBox.getItems().add("Option 1");
        comboBox.getItems().add("Option 2");
        comboBox.getItems().addAll("Option 3", "Option 4");
        comboBox.setPromptText("What is ypur choise?");
        comboBox.setEditable(true);
        
        //comboBox.setOnAction( e -> 
        //			System.out.println("User selected " + comboBox.getValue()));
        comboBox.getSelectionModel().selectedItemProperty().addListener(
        		(v, oldValue, newValue) -> {
        	System.out.println("Previous selection " + oldValue 
        			+ ", new selection " + newValue);
        });
        
        //Button
        Button cmbButton = new Button("Ok");
        cmbButton.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				String message = "Selected choise: " + comboBox.getValue();
		        System.out.println(message);
			}
        });

        //Layout
        VBox cmbLayout = new VBox(10);
        cmbLayout.setPadding(new Insets(20, 20, 20, 20));
        cmbLayout.getChildren().addAll(comboBox, cmbButton);
        
        //----------------------------------------------------------------------
                
    	// Set listView
    	ListView<String> listView = new ListView<>();
    	listView.getItems().add("Option 1");
    	listView.getItems().add("Option 2");
    	listView.getItems().addAll("Option 3", "Option 4");
        listView.getSelectionModel().setSelectionMode(SelectionMode.MULTIPLE);
        
        listView.getSelectionModel().selectedItemProperty().addListener(
        		(v, oldValue, newValue) -> {
        	System.out.println("Selected value " + newValue);
        });

    	//Button
        Button lvButton = new Button("Ok");
        lvButton.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				String message = "Selected options:\n";
				
				ObservableList<String> selectedItems = 
						listView.getSelectionModel().getSelectedItems();
				for(String m: selectedItems) {
		            message += m + "\n";
				}
				
		        System.out.println(message);
			}
        });

        //Layout
        VBox lvLayout = new VBox(10);
        lvLayout.setPadding(new Insets(20, 20, 20, 20));
        lvLayout.getChildren().addAll(listView, lvButton);
        
        //----------------------------------------------------------------------
        
        // Set treeView
        TreeItem<String> rootItem = new TreeItem<String> ("Main Menu");
        rootItem.setExpanded(true);
        
        TreeItem<String> subItem1 = new TreeItem<String> ("Sub Menu 1");
        TreeItem<String> subItem2 = new TreeItem<String> ("Sub Menu 2");
        TreeItem<String> subItem3 = new TreeItem<String> ("Sub Menu 3");
        rootItem.getChildren().add(subItem1);
        rootItem.getChildren().add(subItem2);
        rootItem.getChildren().add(subItem3);
        
        TreeItem<String> subSubItem1 = new TreeItem<String> ("Sub Sub Menu 1");
        TreeItem<String> subSubItem2 = new TreeItem<String> ("Sub Sub Menu 2");
        subItem2.getChildren().add(subSubItem1);
        subItem2.getChildren().add(subSubItem2);
                
        TreeView<String> treeView = new TreeView<String> (rootItem); 
        treeView.getSelectionModel().selectedItemProperty().addListener(
        		(v, oldValue, newValue) -> {
            if (v != null)
                System.out.println("v = " + v.getValue());
            if (oldValue != null)
                System.out.println("oldValue = " + newValue.getValue());
            if (newValue != null)
                System.out.println("newValue = " + newValue.getValue());
        });
        
       	//Button
        Button tvButton = new Button("Ok");
        tvButton.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				String message = "Selected options:\n";
				
				ObservableList<TreeItem<String>> selectedItems = 
						treeView.getSelectionModel().getSelectedItems();
				for(TreeItem<String> m: selectedItems) {
		            message += m.getValue() + "\n";
				}
				
		        System.out.println(message);
			}
        });

        //Layout
        VBox tvLayout = new VBox(10);
        tvLayout.setPadding(new Insets(20, 20, 20, 20));
        tvLayout.getChildren().addAll(treeView, tvButton);
        
        //----------------------------------------------------------------------
        
        // Set tableView
        TableColumn<Person, String> firstNameCol = new TableColumn<>("First Name");
        firstNameCol.setMinWidth(100);
        TableColumn<Person, String> lastNameCol = new TableColumn<>("Last Name");
        lastNameCol.setMinWidth(100);
        TableColumn<Person, String> emailCol = new TableColumn<>("Email");
        emailCol.setMinWidth(100);
        
        TableView<Person> tableView = new TableView<>();
        tableView.getColumns().addAll(firstNameCol, lastNameCol, emailCol);
        
        firstNameCol.setCellValueFactory(new PropertyValueFactory<>("firstName"));
        lastNameCol.setCellValueFactory(new PropertyValueFactory<>("lastName"));
        emailCol.setCellValueFactory(new PropertyValueFactory<>("email"));
        tableView.setItems(data);
        
        tableView.getSelectionModel().setSelectionMode(SelectionMode.MULTIPLE);
        
        tableView.getSelectionModel().selectedItemProperty().addListener(
        		(v, oldValue, newValue) -> {
            System.out.println("Selected item " + newValue.getFirstName() 
            		+ " " + newValue.getLastName());
        });
        
        Button addButton = new Button("Add");
        addButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override
            public void handle(ActionEvent e) {
            	// data.add(new Person("XXXXX", "XXXXX", "XXXXX@example.com"));
                tableView.getItems().add(new Person("YYYYY", "YYYYY", "YYYYY@example.com"));
            }
        });
        
        Button removeButton = new Button("Remove");
        removeButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override
            public void handle(ActionEvent e) {
            	ObservableList<Person> selectedItems = tableView.getSelectionModel().getSelectedItems();
            	
            	ArrayList<Person> persons = new ArrayList<>();
            	for(Person person: selectedItems) {
            		persons.add(person);
				}
            	
            	for(Person person: persons) {
            		tableView.getItems().remove(person);
				}
            }
        });

        //Layout
        VBox tbvLayout = new VBox(10);
        tbvLayout.setPadding(new Insets(20, 20, 20, 20));
        tbvLayout.getChildren().addAll(tableView, addButton, removeButton);
        
        //----------------------------------------------------------------------
        
        HBox layout = new HBox(20);
        layout.getChildren().add(cbLayout);
        layout.getChildren().add(cmbLayout);
        layout.getChildren().add(lvLayout);
        layout.getChildren().add(tvLayout);
        layout.getChildren().add(tbvLayout);
        primaryStage.setTitle("List Views Demo");
        primaryStage.setScene(new Scene(layout));
        primaryStage.show();
    }
}

