package menu;

import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.scene.Scene;
import javafx.scene.control.CheckMenuItem;
import javafx.scene.control.ContextMenu;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuBar;
import javafx.scene.control.MenuItem;
import javafx.scene.control.RadioMenuItem;
import javafx.scene.control.SeparatorMenuItem;
import javafx.scene.control.ToggleGroup;
import javafx.scene.input.KeyCode;
import javafx.scene.input.KeyCodeCombination;
import javafx.scene.input.KeyCombination;
import javafx.scene.input.MouseButton;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.BorderPane;
import javafx.stage.Stage;

public class MenuDemo extends Application {
	@SuppressWarnings("unused")
	private boolean autoSaveFlag;
	
    public static void main(String[] args) {
        launch(args);
    }

    @Override
    public void start(Stage primaryStage) throws Exception {
    	
        //Creating File menu
        Menu fileMenu = new Menu("_File");
        
        Menu newGame = new Menu("New");
        newGame.getItems().add(new MenuItem("Man-Man"));
        newGame.getItems().add(new MenuItem("Man-Computer"));
        newGame.getItems().add(new MenuItem("Computer-Man"));
        newGame.getItems().add(new MenuItem("Computer-Computer"));
        fileMenu.getItems().add(newGame);
        MenuItem openGame = new MenuItem("Open...");
        openGame.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				System.out.println("Open!");
			}
        });
        fileMenu.getItems().add(openGame);
        fileMenu.getItems().add(new MenuItem("Save..."));
        fileMenu.getItems().add(new SeparatorMenuItem());
        MenuItem exit = new MenuItem("Exit");
        exit.setAccelerator(new KeyCodeCombination(KeyCode.X, KeyCombination.CONTROL_DOWN));
        exit.setOnAction(new EventHandler<ActionEvent>() {
			@Override
			public void handle(ActionEvent arg0) {
				System.out.println("Exit!");
			}
        });
        fileMenu.getItems().add(exit);

        //Creating Edit menu
        Menu editMenu = new Menu("_Edit");
        
        editMenu.getItems().add(new MenuItem("Undo"));
        MenuItem redo = new MenuItem("Redo");
        redo.setDisable(true);
        editMenu.getItems().add(redo);

        //Creating Advanced menu
        Menu advancedMenu = new Menu("_Advanced");
        CheckMenuItem autoSave = new CheckMenuItem("Autosave the Game");
        autoSave.setOnAction(e -> {
            if(autoSave.isSelected()) {
                autoSaveFlag = true;
            } else {
            	autoSaveFlag = false;
            }
        });
        autoSave.setSelected(true);
        advancedMenu.getItems().add(autoSave);

        //Creating Difficulty menu
        Menu difficultyMenu = new Menu("_Difficulty");
        ToggleGroup difficultyToggle = new ToggleGroup();

        RadioMenuItem easy = new RadioMenuItem("Easy");
        easy.setSelected(true);
        RadioMenuItem medium = new RadioMenuItem("Medium");
        RadioMenuItem hard = new RadioMenuItem("Hard");

        easy.setToggleGroup(difficultyToggle);
        medium.setToggleGroup(difficultyToggle);
        hard.setToggleGroup(difficultyToggle);

        difficultyMenu.getItems().addAll(easy, medium, hard);

        //Creating main Menu bar
        MenuBar menuBar = new MenuBar();
        menuBar.getMenus().addAll(fileMenu, editMenu, advancedMenu, difficultyMenu);
        
        //Creating Context menu
        ContextMenu contextMenu = new ContextMenu();
        contextMenu.getItems().add(new MenuItem("Copy"));

        //Instantiating the layout class
        BorderPane layout = new BorderPane();
        
        //Setting the menu bar to the pane
        layout.setTop(menuBar);
        
        //Setting the context menu to the pane
        layout.addEventHandler(MouseEvent.MOUSE_CLICKED, new EventHandler<MouseEvent>() {
        	@Override 
        	public void handle(MouseEvent e) {
        		if (e.getButton() == MouseButton.SECONDARY)
        			contextMenu.show(primaryStage, e.getScreenX(), e.getScreenY());
        		}
        });
        
        //Creating a scene object
        Scene scene = new Scene(layout, 400, 300);
        
        //Setting title to the Stage
      	primaryStage.setTitle("Menu Demo");
      		
      	//Adding scene to the stage 
      	primaryStage.setScene(scene);       
      		
      	//Displaying the contents of the stage
      	primaryStage.show();
    }


}